@@ -48,13 +48,16 @@ def receiver_task_retry(request=None, reason=None, einfo=None, **kwargs):
 
 
 def receiver_task_success(result=None, **kwargs):
-    logger.info("task_succeed", result=str(result))
+    with structlog.threadlocal.tmp_bind(logger):
+        signals.pre_task_succeeded.send(
+            sender=receiver_task_pre_run, logger=logger, result=result
+        )
+        logger.info("task_succeeded")
 
 
 def receiver_task_failure(
     task_id=None, exception=None, traceback=None, einfo=None, *args, **kwargs
 ):
-
     logger.exception("task_failed", error=str(exception), exception=exception)
 
 
