@@ -3,7 +3,6 @@ import uuid
 import structlog
 import traceback
 from django.http import Http404
-from django.conf import settings
 
 from .. import signals
 
@@ -28,10 +27,6 @@ class RequestMiddleware:
     """
 
     def __init__(self, get_response):
-        self.log_user_in_request_finished = getattr(
-            settings, "DJANGO_STRUCTLOG_LOG_USER_IN_REQUEST_FINISHED", False
-        )
-
         self.get_response = get_response
         self._raised_exception = False
 
@@ -48,10 +43,7 @@ class RequestMiddleware:
 
         with structlog.threadlocal.tmp_bind(logger):
             logger.bind(request_id=request_id)
-
-            if hasattr(request, "user"):
-                logger.bind(**self.get_request_user(request))
-
+            self.bind_user_id(request),
             if correlation_id:
                 logger.bind(correlation_id=correlation_id)
 
@@ -69,11 +61,15 @@ class RequestMiddleware:
             self._raised_exception = False
             response = self.get_response(request)
             if not self._raised_exception:
-                logger.info(
-                    "request_finished",
-                    code=response.status_code,
+                self.bind_user_id(request),
+                signals.bind_extra_request_finished_metadata.send(
+                    sender=self.__class__,
                     request=request,
-                    **self.get_request_finished_optional_user_kwargs(request),
+                    logger=logger,
+                    response=response,
+                )
+                logger.info(
+                    "request_finished", code=response.status_code, request=request
                 )
 
         return response
@@ -89,21 +85,19 @@ class RequestMiddleware:
 
         traceback_object = exception.__traceback__
         formatted_traceback = traceback.format_tb(traceback_object)
+        self.bind_user_id(request),
+        signals.bind_extra_request_failed_metadata.send(
+            sender=self.__class__, request=request, logger=logger, exception=exception
+        )
         logger.exception(
             "request_failed",
             code=500,
             request=request,
             error=exception,
             error_traceback=formatted_traceback,
-            **self.get_request_finished_optional_user_kwargs(request),
         )
 
-    def get_request_finished_optional_user_kwargs(self, request):
-        if hasattr(request, "user") and self.log_user_in_request_finished:
-            return self.get_request_user(request)
-        else:
-            return {}
-
     @staticmethod
-    def get_request_user(request):
-        return {"user_id": request.user.pk}
+    def bind_user_id(request):
+        if hasattr(request, "user"):
+            logger.bind(user_id=request.user.pk)
